@@ -10,7 +10,7 @@ require QObject;
 
 @ISA = qw(DynaLoader QObject);
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 bootstrap QTimer $VERSION;
 
 1;
@@ -35,6 +35,10 @@ singleShot,
 start,
 stop
 
+=head2 Overridden functions
+
+event
+
 =head1 DESCRIPTION
 
 What you see is what you get.
